@@ -115,9 +115,8 @@ class Cdo(object):
     self.cdfMod                 = cdfMod.lower()
     self.env                    = env
     self.debug                  = True if 'DEBUG' in os.environ else debug
-    self.outputOperatorsPattern = '(diff|info|output|griddes|zaxisdes|show|ncode|ndate|nlevel|nmon|nvar|nyear|ntime|npar|gradsdes|pardes)'
-
-    self.libs        = self.getSupportedLibs()
+    self.outputOperators        = ['cdiread','cmor','codetab','conv_cmor_table','diff','diffc','diffn','diffp','diffv','dump_cmor_table','dumpmap','filedes','ggstat','ggstats','gmtcells','gmtxyz','gradsdes','griddes','griddes2','gridverify','info','infoc','infon','infop','infos','infov','map','ncode','ncode','ndate','ngridpoints','ngrids','nlevel','nmon','npar','ntime','nvar','nyear','output','outputarr','outputbounds','outputboundscpt','outputcenter','outputcenter2','outputcentercpt','outputext','outputf','outputfld','outputint','outputkey','outputsrv','outputtab','outputtri','outputts','outputvector','outputvrml','outputxyz','pardes','partab','partab2','seinfo','seinfoc','seinfon','seinfop','showcode','showdate','showformat','showlevel','showltype','showmon','showname','showparam','showstdname','showtime','showtimestamp','showunit','showvar','showyear','sinfo','sinfoc','sinfon','sinfop','sinfov','spartab','specinfo','tinfo','vardes','vct','vct2','verifygrid','vlist','zaxisdes']
+    self.libs                   = self.getSupportedLibs()
 
     self.logging                = logging
     self.logFile                = logFile
@@ -136,14 +135,6 @@ class Cdo(object):
           return isinstance(myString,str)
 
   def call(self,cmd):
-    if self.debug:
-      print('# DEBUG =====================================================================')
-      if {} != self.env:
-        for k,v in list(self.env.items()):
-          print("ENV: " + k + " = " + v)
-      print('CALL:'+' '.join(cmd))
-      print('# DEBUG =====================================================================')
-
     if self.logging and '-h' != cmd[1]:
       self.logger.info(u' '.join(cmd))
 
@@ -156,9 +147,25 @@ class Cdo(object):
                             stdout = subprocess.PIPE)
 
     retvals = proc.communicate()
+    stdout  = retvals[0].decode("utf-8")
+    stderr  = retvals[1].decode("utf-8")
 
-    return {"stdout"     : retvals[0].decode("utf-8")
-           ,"stderr"     : retvals[1].decode("utf-8")
+    if self.debug:
+      print('# DEBUG - start =============================================================')
+      if {} != self.env:
+        for k,v in list(self.env.items()):
+          print("ENV: " + k + " = " + v)
+      print('CALL  :' + ' '.join(cmd))
+      print('STDOUT:')
+      if (0 != len(stdout.strip())):
+        print(stdout)
+      print('STDERR:')
+      if (0 != len(stderr.strip())):
+        print(stderr)
+      print('# DEBUG - end ===============================================================')
+
+    return {"stdout"     : stdout
+           ,"stderr"     : stderr
            ,"returncode" : proc.returncode}
 
   def hasError(self,method_name,cmd,retvals):
@@ -167,7 +174,9 @@ class Cdo(object):
     if ( 0 != retvals["returncode"] ):
       print("Error in calling operator " + method_name + " with:")
       print(">>> "+' '.join(cmd)+"<<<")
-      print(retvals["stderr"])
+      print('STDOUT:' + retvals["stdout"])
+      print('STDERR:' + retvals["stderr"])
+
       if self.logging:
           self.logger.error(cmd + " with:" + retvals["stderr"])
       return True
@@ -179,15 +188,17 @@ class Cdo(object):
     @auto_doc(method_name, self)
     def get(self, *args,**kwargs):
       operator          = [method_name]
-      operatorPrintsOut = re.search(self.outputOperatorsPattern,method_name)
+      operatorPrintsOut = method_name in self.outputOperators
 
       if args.__len__() != 0:
         for arg in args:
           operator.append(arg.__str__())
 
       #build the cdo command
-      #1. the cdo command
+      #0. the cdo command
       cmd = [self.CDO]
+      #1. OVERWRITE EXISTING FILES
+      cmd.append('-O')
       #2. options
       if 'options' in kwargs:
           cmd += kwargs['options'].split()
